/**
 * 
 *  Copyright (C) 2000-2004 Enterprise Distributed Technologies Ltd
 *
 *  www.enterprisedt.com
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Bug fixes, suggestions and comments should be sent to support@enterprisedt.com
 *
 *  Change Log:
 *
 *    $Log: Demo.java,v $
 *    Revision 1.2  2004/05/01 16:04:08  bruceb
 *    removed log stuff
 *
 *    Revision 1.1  2004/05/01 11:40:46  bruceb
 *    demo files
 *
 *
 */

import com.enterprisedt.net.ftp.FTPClient;
import com.enterprisedt.net.ftp.FTPTransferType;
import com.enterprisedt.net.ftp.FTPConnectMode;

/**
 *  Simple test class for FTPClient
 *
 *  @author      Hans Andersen
 *  @author      Bruce Blackshaw
 */
public class Demo {
    
    /**
     *  Revision control id
     */
    private static String cvsId = "@(#)$Id: Demo.java,v 1.2 2004/05/01 16:04:08 bruceb Exp $";
    
    /**
     * Standard main()
     * 
     * @param args  standard args
     */
    public static void main(String[] args) {
               
        // we want remote host, user name and password
        if (args.length < 3) {
            usage();
            System.exit(1);
        }

        // assign args to make it clear
        String host = args[0];
        String user = args[1];
        String password = args[2];

        FTPClient ftp = null;

        try {
            // set up client
            System.out.println("Connecting");

            ftp = new FTPClient(host);

             // login
            System.out.println("Logging in");
            ftp.login(user, password);

            // set up passive ASCII transfers
            System.out.println("Setting up passive, ASCII transfers");
            ftp.setConnectMode(FTPConnectMode.PASV);
            ftp.setType(FTPTransferType.ASCII);

            // get directory and print it to console            
            System.out.println("Directory before put:");
            String[] files = ftp.dir(".", true);
            for (int i = 0; i < files.length; i++)
                System.out.println(files[i]);

            // copy file to server 
            System.out.println("Putting file");
            ftp.put("test.txt", "test.txt");

            // get directory and print it to console            
            System.out.println("Directory after put");
            files = ftp.dir(".", true);
            for (int i = 0; i < files.length; i++)
                System.out.println(files[i]);

            // copy file from server
            System.out.println("Getting file");
            ftp.get("test.txt" + ".copy", "test.txt");

            // delete file from server
            System.out.println("Deleting file");
            ftp.delete("test.txt");

            // get directory and print it to console            
            System.out.println("Directory after delete");
            files = ftp.dir("", true);
            for (int i = 0; i < files.length; i++)
                System.out.println(files[i]);

            // Shut down client                
            System.out.println("Quitting client");
            ftp.quit();

            System.out.println("Test complete");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }   
    
    /**
     *  Basic usage statement
     */
    public static void usage() {

        System.out.println("Usage: Demo remotehost user password");
    }

}
